@@ -350,6 +350,11 @@ return [
 			'url' => '/api/settings/llm',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'settings#setImportanceClassificationEnabledByDefault',
+			'url' => '/api/settings/importance-classification-default',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'trusted_senders#setTrusted',
 			'url' => '/api/trustedsenders/{email}',
