@@ -30,12 +30,23 @@ OC.L10N.register(
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register" : "Registrar",
+    "Compose new message" : "Escribir mensaje nuevo",
+    "Newer message" : "Mensaje más nuevo",
+    "Older message" : "Mensaje más antiguo",
+    "Toggle star" : "Alternar favoritos",
+    "Toggle unread" : "Alternar no leídos",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Actualizar",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Choose" : "Seleccionar",
     "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
@@ -46,11 +57,11 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Forward" : "Adelante",
     "All day" : "Todo el día",
+    "Description" : "Descripción",
     "Create" : "Crear",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
-    "Choose" : "Seleccionar",
     "Other" : "Otro",
     "Reply" : "Responder",
     "Import into calendar" : "Importar al calendario",
@@ -67,18 +78,15 @@ OC.L10N.register(
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
-    "Refresh" : "Actualizar",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
-    "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Clear" : "Limpiar",
-    "Search" : "Buscar",
-    "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
@@ -94,15 +102,6 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
-    "Compose new message" : "Escribir mensaje nuevo",
-    "Newer message" : "Mensaje más nuevo",
-    "Older message" : "Mensaje más antiguo",
-    "Toggle star" : "Alternar favoritos",
-    "Toggle unread" : "Alternar no leídos",
-    "Archive" : "Archivar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
