@@ -224,6 +224,7 @@ OC.L10N.register(
     "Report this bug" : "Zgłoś ten błąd",
     "All day" : "Cały dzień",
     "Select calendar" : "Wybierz kalendarz",
+    "Description" : "Opis",
     "Create" : "Utwórz",
     "Event created" : "Utworzono wydarzenie",
     "Could not create event" : "Nie można utworzyć wydarzenia",
@@ -363,6 +364,7 @@ OC.L10N.register(
     "Close" : "Zamknij",
     "Search parameters" : "Wyszukaj parametry",
     "Body" : "Treść",
+    "Date" : "Data",
     "Pick a start date" : "Wybierz datę rozpoczęcia",
     "Pick an end date" : "Wybierz datę zakończenia",
     "Tags" : "Etykiety",
@@ -370,7 +372,7 @@ OC.L10N.register(
     "Marked as" : "Oznaczono jako",
     "Has attachments" : "Posiada załączniki",
     "Clear" : "Wyczyść ",
-    "Date" : "Data",
+    "Last 7 days" : "Ostatnie 7 dni",
     "Disabled" : "Wyłączone",
     "Enabled" : "Włączone",
     "Sieve Host" : "Host Sieve",
