@@ -9,6 +9,7 @@ OC.L10N.register(
     "Save" : "Save",
     "Connect" : "Poveži se",
     "Password required" : "Potrebna je lozinka",
+    "Signature" : "Potpis",
     "Cancel" : "Otkaži",
     "Delete" : "Delete",
     "Search" : "Search",
@@ -28,13 +29,14 @@ OC.L10N.register(
     "Reply" : "Odgovori",
     "Move" : "Premesti",
     "Remove account" : "Ukloni nalog",
+    "Loading …" : "Učitavanje...",
     "Mark all as read" : "Označi sve kao pročitano",
     "Clear cache" : "Očisti keš",
     "Add" : "Dodaj",
     "Close" : "Zatvori",
     "Body" : "Telo",
-    "Tags" : "Oznake",
     "Date" : "Date",
+    "Tags" : "Oznake",
     "Remove" : "Ukloni",
     "General" : "Opšte",
     "User" : "User",
