@@ -35,7 +35,6 @@ use Horde_Imap_Client_Search_Query;
 use Horde_Imap_Client_Socket;
 use Horde_Mime_Exception;
 use Horde_Mime_Headers;
-use Horde_Mime_Mail;
 use Horde_Mime_Part;
 use Html2Text\Html2Text;
 use OCA\Mail\Attachment;
@@ -398,7 +397,7 @@ class MessageMapper {
 	 */
 	public function save(Horde_Imap_Client_Socket $client,
 		Mailbox $mailbox,
-		Horde_Mime_Mail $mail,
+		string $mail,
 		array $flags = []): int {
 		$flags = array_merge([
 			Horde_Imap_Client::FLAG_SEEN,
@@ -408,7 +407,7 @@ class MessageMapper {
 			$mailbox->getName(),
 			[
 				[
-					'data' => $mail->getRaw(),
+					'data' => $mail,
 					'flags' => $flags,
 				]
 			]
