@@ -25,13 +25,13 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Integration\KItinerary;
 
-use ChristophWurst\KItinerary\Adapter;
-use ChristophWurst\KItinerary\Bin\BinaryAdapter;
-use ChristophWurst\KItinerary\Exception\KItineraryRuntimeException;
-use ChristophWurst\KItinerary\Flatpak\FlatpakAdapter;
-use ChristophWurst\KItinerary\Itinerary;
-use ChristophWurst\KItinerary\ItineraryExtractor as Extractor;
-use ChristophWurst\KItinerary\Sys\SysAdapter;
+use Nextcloud\KItinerary\Adapter;
+use Nextcloud\KItinerary\Bin\BinaryAdapter;
+use Nextcloud\KItinerary\Exception\KItineraryRuntimeException;
+use Nextcloud\KItinerary\Flatpak\FlatpakAdapter;
+use Nextcloud\KItinerary\Itinerary;
+use Nextcloud\KItinerary\ItineraryExtractor as Extractor;
+use Nextcloud\KItinerary\Sys\SysAdapter;
 use Psr\Log\LoggerInterface;
 
 class ItineraryExtractor {
