@@ -26,8 +26,10 @@ declare(strict_types=1);
 namespace OCA\Mail\Listener;
 
 use OCA\Mail\Contracts\IUserPreferences;
+use OCA\Mail\Db\Recipient;
 use OCA\Mail\Events\MessageSentEvent;
 use OCA\Mail\Service\AutoCompletion\AddressCollector;
+use OCA\Mail\Service\TransmissionService;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use Psr\Log\LoggerInterface;
@@ -48,7 +50,8 @@ class AddressCollectionListener implements IEventListener {
 
 	public function __construct(IUserPreferences $preferences,
 		AddressCollector $collector,
-		LoggerInterface $logger) {
+		LoggerInterface $logger,
+		private TransmissionService $transmissionService) {
 		$this->collector = $collector;
 		$this->logger = $logger;
 		$this->preferences = $preferences;
@@ -65,10 +68,12 @@ class AddressCollectionListener implements IEventListener {
 
 		// Non-essential feature, hence we catch all possible errors
 		try {
-			$message = $event->getMessage();
-			$addresses = $message->getTo()
-				->merge($message->getCC())
-				->merge($message->getBCC());
+			$message = $event->getLocalMessage();
+			$to = $this->transmissionService->getAddressList($message, Recipient::TYPE_TO);
+			$cc = $this->transmissionService->getAddressList($message, Recipient::TYPE_CC);
+			$bcc = $this->transmissionService->getAddressList($message, Recipient::TYPE_BCC);
+
+			$addresses = $to->merge($cc)->merge($bcc);
 
 			$this->collector->addAddresses($event->getAccount()->getUserId(), $addresses);
 		} catch (Throwable $e) {
