@@ -42,6 +42,9 @@ class Message implements IMessage {
 	/** @var AddressList */
 	private $to;
 
+	/** @var AddressList */
+	private $replyTo;
+
 	/** @var AddressList */
 	private $cc;
 
@@ -63,6 +66,7 @@ class Message implements IMessage {
 	public function __construct() {
 		$this->from = new AddressList();
 		$this->to = new AddressList();
+		$this->replyTo = new AddressList();
 		$this->cc = new AddressList();
 		$this->bcc = new AddressList();
 	}
@@ -126,6 +130,22 @@ class Message implements IMessage {
 		$this->to = $to;
 	}
 
+	/**
+	 * @return AddressList
+	 */
+	public function getReplyTo(): AddressList {
+		return $this->replyTo;
+	}
+
+	/**
+	 * @param AddressList $replyTo
+	 *
+	 * @return void
+	 */
+	public function setReplyTo(AddressList $replyTo) {
+		$this->replyTo = $replyTo;
+	}
+
 	/**
 	 * @return AddressList
 	 */
