@@ -24,6 +24,8 @@ declare(strict_types=1);
 namespace OCA\Mail\Service\AutoConfig;
 
 use Psr\Log\LoggerInterface;
+use function array_combine;
+use function asort;
 
 class MxRecord {
 	/** @var LoggerInterface */
@@ -38,19 +40,23 @@ class MxRecord {
 	 * @return string[]
 	 */
 	public function query(string $host) {
-		if (getmxrr($host, $mxRecords, $mxWeight) === false) {
+		if (getmxrr($host, $mxRecords, $mxWeights) === false) {
 			$this->logger->debug("no MX records for host <$host> found");
 			return [];
 		}
-		$mxRecords = array_filter($mxRecords, static function ($record) {
+
+		// Sort MX records by weight
+		$sortedRecords = array_combine($mxRecords, $mxWeights);
+		asort($sortedRecords, SORT_NUMERIC);
+
+		$mxRecords = array_filter(array_keys($sortedRecords), static function ($record) {
 			return !empty($record);
 		});
-		$this->logger->debug("found " . count($mxRecords) . " MX records for host <$host>");
+		$this->logger->debug("found " . count($sortedRecords) . " MX records for host <$host>");
 		if (empty(($mxRecords))) {
 			return [];
 		}
 
-		// TODO: sort by weight
 		return $this->sanitizedRecords($mxRecords);
 	}
 
